<html>
<head>
	<title>PHP Front-end for the CICS Catalog Application</title>
	<style>
	  body { font-family: arial, "lucida console", sans-serif }
	  th { background-color: black; color: white; }
	  tr.odd { background-color:#ccccff; }
	  tr.even { background-color:#eeeeff; }
	</style>
</head>
<body>
<h2>CICS Example Catalog Application</h2>

<?php
// Import the generated classes for the CICS program that the script will interact with.
java_import('sample.DFH0XCMN');

// Render page according to 'action' POST item
$action = isset($_POST['action']) ? $_POST['action'] : 'listItems';
switch ($action) {
case 'listItems':
  showItemList();
  break;
case 'gatherOrderDetails':
  gatherOrderDetails();
  break;
default:
  echo "Unknown action: $action";
}

/**************************
 * Render a paginated table that lists the items in the catalog,
 * and a form to begin an order.
 **************************/ 
function showItemList() {
  // Render table header
  echo <<<EOT
<table border="1" cellspacing="0" width="60%">
  <tr>
    <th>Item</th>
    <th>Description</th>
    <th>Cost</th>
    <th>Stock</th>
    <th>On Order</th>
  </tr>
EOT;

  // Call CICS program to get list of items
  $start = isset($_POST['start']) ? $_POST['start'] : 0;
  $commAreaIn = new DFH0XCMN(); 
  $commAreaIn->setCaRequestId('01INQC');
  $commAreaIn->setCaListStartRef($start);    
  $commAreaOut = new DFH0XCMN(); 
  $program = new CICSProgram("DFH0XCMN");                   
  try {
    $program->link($commAreaIn);
  } catch (CICSException $e) {
    echo $e->getMessage();
    exit;
  }

  // Iterate over items and print info in table rows
  for($a = 0; $a < $commAreaIn->getCaItemCount(); $a++) {
    $caCatItem = $commAreaIn->getCaCatItem($a);
    echo "<tr class='" . (($a % 2) == 1 ? 'odd' : 'even') . "'>";
	$itemRef = sprintf("%04.d", $caCatItem->getCaItemRef());
    echo "<td align='right'><strong>$itemRef</strong></td>";
    echo '<td>' . $caCatItem->getCaDescription() . '</td>';
    echo '<td align="right">' . ltrim($caCatItem->getCaCost(), "0") . '</td>';
    echo '<td align="right">' . $caCatItem->getInStock() . '</td>';
    echo '<td align="right">' . $caCatItem->getOnOrder() . '</td>';
	echo "</tr>\n";
  }
  echo "</table>\n";

  // Render buttons to navigate list
  $disabled = ($start==0) ? 'disabled' : '';
  echo <<< EOT
  <span>
  <div style='width:60%'>
  <div style='float:left'>
  <form method='POST' action='catalog.php'>
  <input type='hidden' name='action' value='listItems' />
  <input type='hidden' name='start' value='0' />
  <input $disabled type='submit' name='submit' value='Back to start...' />
  </form>
  </div>
  <div style='float:right'>
  <form method='POST' action='catalog.php' />
  <input type='hidden' name='action' value='listItems' />
  <input type='hidden' name='start' value='$itemRef' />
  <input type='submit' name='submit' value='More items...' />
  </form>
  </div>
  </div>
EOT;

  // Render form to start an order
  echo <<<EOT
  <div style='float:left; margin-top:30px;'>
  <form method='POST' action='catalog.php'>
  <input type='hidden' name='action' value='gatherOrderDetails' />
  <label name='item'>Enter item number to order:<label>
  <input name='item' type='text' size='4' maxlength='4' value='' />
  <input type='submit' name='submit' value='Order item!' />
  </form>
  </div>
EOT;

}

/**************************
 * Display form to gather the details of an order
 * and allow user to submit the order.
 **************************/ 
function gatherOrderDetails() {
  echo <<<EOT
<h3>Details of your order</h3>
<table border="1" cellspacing="0" width="60%">
  <tr>
    <th>Item</th>
    <th>Description</th>
    <th>Cost</th>
    <th>Stock</th>
    <th>On Order</th>
  </tr>
EOT;

  $itemNum = $_POST['item'];                       
  $itemLen = strlen($itemNum);
  $commAreaIn = new DFH0XCMN(); 
  $commAreaIn->setCaRequestId('01INQS');     
  $commAreaIn->setCaItemRefReq($itemNum);    
  $commAreaOut = new DFH0XCMN(); 
  $program = new CICSProgram("DFH0XCMN");                   
  try {
    $program->link($commAreaIn);
  } catch (CICSException $e) {
    echo $e->getMessage();
    exit;
  }
  $description = $commAreaIn->getCaSnglDescription();
  $number = $commAreaIn->getCaSnglItemRef();
  $number = sprintf("%04.d", $number);   
  $cost = $commAreaIn->getCaSnglCost();
  $cost = ltrim($cost,"0");
  $stock = $commAreaIn->getInSnglStock();
  $onOrder = $commAreaIn->getOnSnglOrder();
  echo <<<EOT
  <tr>
     <td align="right">$number</td>
     <td>$description</td>
     <td align="right">$cost</td>
     <td align="right">$stock</td>
     <td align="right">$onOrder</td>
  </tr>
</table>
<form method="POST" action="processOrder.php">  
<table>
  <tr>
    <td>Order Quantity</td>                                                                             
    <td align="right"><input type="text" name="orderQuantity" value="0" size="3" maxlength="3"></td></tr>
  <tr>
    <td>User Name</td>                                                                       
    <td><input type="text" name="userName" value="" size="8" maxlength="8"></td>
  </tr>      
  <tr>
    <td>Charge Department</td>                                                                               
    <td><input type="text" name="chargeDepartment" value="" size="8" maxlength="8"></td>
  </tr>  
</table>
<br>
<input type="hidden" name="itemNum" value="$number">                                           
<input type="hidden" name="description" value="$description">                                  
<input type="hidden" name="cost" value="$cost">
<input type="submit" name="submit" value="Order">   
</form>
EOT;
}
?>
</body>
</html>
