<?php
/**
 * Simple filesystem based data store for Spaceship.php.
 */
class DataStore {
	const DIR='shipData';

	function __construct() {
		if (!file_exists(DataStore::DIR)) {
			// If the datastore does not exists, create it at populate it with some data
			mkdir(DataStore::DIR);
			file_put_contents(DataStore::DIR . '/ship.1', serialize(array('x'=>1, 'y'=>1)));
			file_put_contents(DataStore::DIR . '/ship.2', serialize(array('x'=>2, 'y'=>2)));
		}

		if (!file_exists(DataStore::DIR) || !is_dir(DataStore::DIR)) {
			die("Could not create datastore directory: " + DataStore::DIR);
		}
		
	}

	function getAll() {
		$shipDataDir = dir(DataStore::DIR);
		$ships = array();
		while (false !== ($entry = $shipDataDir->read())) {
			if (preg_match('/ship\.(\d+)/', $entry, $matches)) {
				$id = $matches[1];
				$ship = unserialize(file_get_contents(DataStore::DIR . '/' . $entry));
				$ships[$id] = $ship;
			}
		}
		return $ships;
	}

	function get($id) {
		$filename = DataStore::DIR . '/ship.' . $id;
		if (file_exists($filename)) {
			return unserialize(file_get_contents($filename));
		}
	}

	function put($id, $ship) {
		$filename = DataStore::DIR . '/ship.' . $id;
		$returnData = null;
		if (file_exists($filename)) {
			$returnData = unserialize(file_get_contents($filename));
		}
		file_put_contents($filename, serialize($ship));
		return $returnData;
	}

	function remove($id) {
		$filename = DataStore::DIR . '/ship.' . $id;
		$returnData = null;
		if (file_exists($filename)) {
			$returnData = unserialize(file_get_contents($filename));
			unlink($filename);
		}
		return $returnData;
	}
}
?>