<?php
include('DataStore.php');
$data = new DataStore;

class Spaceship {

  /**
   * Displays JSON representation of ships matching search criteria
   * in form data, or of all ships if no search criteria is supplied.
   */
  function onList() {
    global $data;

    // Get seach criteria (from the query string)
    $searchCriteria['x'] = zget('/request/params/x');
    $searchCriteria['y'] = zget('/request/params/y');

    // Get all ships matching the criteria
    $results = array();
    foreach ($data->getAll() as $id=>$ship) {
      if (($searchCriteria['x'] === null || $searchCriteria['x'] == $ship['x']) 
           && ($searchCriteria['y'] === null || $searchCriteria['y'] == $ship['y'])) {
        $results[$id] = $ship;
      }
    }

    echo json_encode($results);
  }


  /**
   * Creates and stores a new ship based on form data.
   * Fail if invalid data is supplied or if a ship with the supplied ID already exists.
   * Displays a JSON representation of the newly created ship.
   */
  function onCreate() {
    global $data;

    // Get ship attributes from form data.
    $id = (int)zget('/request/params/id');
    $newShip['x'] = zget('/request/params/x');
    $newShip['y'] = zget('/request/params/y');

    if (!verifyShip($newShip)) {
      header('HTTP/1.0 400 Bad Request');
      echo 'ERROR: could not create new ship with this data:';
      print_r($newShip);
      return;
    }

    if ($data->get($id) !== null) {
      header('HTTP/1.0 409 Conflict');
      echo "ERROR: Ship with id $id already exists.";
      return;
    }

    // Store the ship and return the newly stored ship.
    $data->put($id, $newShip);
    echo json_encode($data->get($id));
  }


  /**
   * Displays a JSON representation of a ship or an attribute of a ship
   * as determined by the inbound URI.
   */
  function onRetrieve() {
    global $data;

    //Get the requested ship ID
    $id = zget('/request/params/SpaceshipId');
    $ship = $data->get($id);

    if ($ship === null) {
      header('HTTP/1.0 404 Not Found');
      echo "ERROR: Ship $id not found.";
      return;
    }

    //Return only the requested attribute
    switch (zget('/event/pathInfo')) { 
      case '/x':
        echo json_encode($ship['x']);
        break;
      case '/y':
        echo json_encode($ship['y']);
        break;
      default:
        echo json_encode($ship);
    }
  }


  /**
   * Updates one or more attributes of a ship as determined by the
   * inbound URI and the non form-encoded JSON input data.
   */
  function onUpdate() {
    global $data;

    $id = zget('/request/params/SpaceshipId');
    $ship = $data->get($id);
    if ($ship === null) {
      header('HTTP/1.0 201 Created');
    }

    // Assume non form-ecoded, JSON input.
    // Attributes to update depend on URI.
    $input = zget('/request/input/transcoded');
    switch (zget('/event/pathInfo')) { 
      case '/x':
        $newShip['x'] = json_decode($input);
        break;
      case '/y':
        $newShip['y'] = json_decode($input);
        break;
      default:
        $newShip = (array)json_decode($input);
	  }

    // Update existing ship with any incoming, non-null data.
    if (!empty($newShip['x'])) {
      $ship['x'] = (int)$newShip['x'];
    }
    if (!empty($newShip['y'])) {
      $ship['y'] = (int)$newShip['y'];
    }

    if (!verifyShip($ship)) {
      header('HTTP/1.0 400 Bad Request');
      echo 'ERROR: could not update new ship with this data:';
      print_r($ship);
      return;
    }

    //Store updated ship and return the old version.
    $oldShip = $data->put($id, $ship);
    if (!empty($oldShip)) {
      echo json_encode($oldShip);
    } else {
      echo "Created ship $id";
    }
    
  }

  /**
   * Deletes a ship.
   */
  function onDelete() {
    global $data;

    $id = zget('/request/params/SpaceshipId');
    $shipData = $data->get($id);
    if ($shipData === null) {
      header('HTTP/1.0 404 Not Found');
      echo "ERROR: Ship $id not found, could not delete it.";
      return;
    }

    $deleted = $data->remove($id);
    echo json_encode($deleted);
  }

}

function verifyShip($ship) {
  if (!is_array($ship)) {
    return false;
  }

  foreach (array('x', 'y') as $element) {
    if (empty($ship[$element])) {
      return false;
    }
    if ($ship[$element] < 1) {
      return false;
    }
  }
  return true;
}
?>